﻿using System;
using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트
        /// </summary>
        private LightningChartUltimate chart = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            InitializeChart();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 차트 초기화하기 - InitializeChart()

        /// <summary>
        /// 차트 초기화하기
        /// </summary>
        private void InitializeChart()
        {
            this.chart = new LightningChartUltimate();
            
            this.chart.BeginUpdate();

            this.chart.Name   = "chart";
            this.chart.Parent = this;
            this.chart.Dock   = DockStyle.Fill;

            this.chart.Title.Font = Font;
            this.chart.Title.Text = "2D 라인 차트";

            this.chart.ViewXY.LegendBoxes[0].Visible = false;

            AxisX axisX = this.chart.ViewXY.XAxes[0];

            axisX.Title.Font = Font;
            axisX.Title.Text = "X축";
            axisX.ScrollMode = XAxisScrollMode.None;
            axisX.ValueType  = AxisValueType.Number;

            axisX.SetRange(0, 20);

            AxisY axisY = this.chart.ViewXY.YAxes[0];

            axisY.Title.Font = Font;
            axisY.Title.Text = "Y축";

            axisY.SetRange(0, 100);

            ChartHelper.SetDarkFlatStyle(this.chart);

            Random random = new Random();

            int pointCount = 21;

            SeriesPoint[] pointArray = new SeriesPoint[pointCount];

            for(int i = 0; i < pointCount; i++)
            {
                pointArray[i].X = (double)i;
                pointArray[i].Y = 100.0 * random.NextDouble();
            }

            PointLineSeries series = new PointLineSeries(this.chart.ViewXY, axisX, axisY);

            series.PointsVisible = true;
            series.Points        = pointArray;
            
            this.chart.ViewXY.PointLineSeries.Add(series);

            LineSeriesCursor cursor = new LineSeriesCursor(this.chart.ViewXY, axisX);

            cursor.ValueAtXAxis = 5;
            cursor.SnapToPoints = true;

            this.chart.ViewXY.LineSeriesCursors.Add(cursor);

            this.chart.EndUpdate();

            ChartTools.ZoomToDataAndLabelsArea(this.chart);
        }

        #endregion
    }
}